Welcome to Orange3 Image Analytics documentation!
=================================================


Widgets
-------

.. toctree::
   :maxdepth: 1

   widgets/importimages
   widgets/imageviewer
   widgets/imageembedding
   widgets/imagegrid
   widgets/saveimages

Scripting
---------

.. toctree::
   :maxdepth: 1

   scripting/image_embedder


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

